@@ -387,14 +387,12 @@ supports_contact_search_cb (GObject *conn,
     gpointer user_data)
 {
   FilterCallbackData *data = user_data;
-  GError *error = NULL;
+  GError *myerr = NULL;
   TpCapabilities *caps;
 
-  if (!tp_proxy_prepare_finish (conn, result, &error))
+  if (!tp_proxy_prepare_finish (conn, result, &myerr))
     {
-      DEBUG ("Error preparing the connection: %s", error->message);
       data->callback (FALSE, data->user_data);
-      g_error_free (error);
       g_slice_free (FilterCallbackData, data);
       return;
     }
@@ -603,6 +601,7 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   /* Pack the dialog */
   priv->notebook = gtk_notebook_new ();
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->notebook), FALSE);
+  g_object_set (priv->notebook, "margin", 6, NULL);
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
