@@ -46,7 +46,6 @@
 #include "empathy-ui-utils.h"
 #include "empathy-share-my-desktop.h"
 #include "empathy-linking-dialog.h"
-#include "empathy-call-utils.h"
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyIndividualMenu)
 
@@ -543,9 +542,7 @@ empathy_individual_audio_call_menu_item_activated (GtkMenuItem *item,
 {
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
-  empathy_call_new_with_streams (empathy_contact_get_id (contact),
-      empathy_contact_get_account (contact),
-      TRUE, FALSE,
+  empathy_call_new_with_streams (contact, TRUE, FALSE,
       gtk_get_current_event_time ());
 }
 
@@ -587,9 +584,7 @@ empathy_individual_video_call_menu_item_activated (GtkMenuItem *item,
 {
   g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
-  empathy_call_new_with_streams (empathy_contact_get_id (contact),
-      empathy_contact_get_account (contact),
-      TRUE, TRUE,
+  empathy_call_new_with_streams (contact, TRUE, TRUE,
       gtk_get_current_event_time ());
 }
 
@@ -755,8 +750,7 @@ static void
 favourite_menu_item_toggled_cb (GtkCheckMenuItem *item,
   FolksIndividual *individual)
 {
-  folks_favourite_details_set_is_favourite (
-      FOLKS_FAVOURITE_DETAILS (individual),
+  folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual),
       gtk_check_menu_item_get_active (item));
 }
 
@@ -768,8 +762,7 @@ empathy_individual_favourite_menu_item_new (FolksIndividual *individual)
   item = gtk_check_menu_item_new_with_label (_("Favorite"));
 
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-      folks_favourite_details_get_is_favourite (
-          FOLKS_FAVOURITE_DETAILS (individual)));
+      folks_favouritable_get_is_favourite (FOLKS_FAVOURITABLE (individual)));
 
   g_signal_connect (item, "toggled",
       G_CALLBACK (favourite_menu_item_toggled_cb), individual);
@@ -830,15 +823,12 @@ empathy_individual_edit_menu_item_new (FolksIndividual *individual)
   if (empathy_individual_manager_initialized ())
     {
       TpConnection *connection;
-      EmpathyIndividualManagerFlags flags;
 
       manager = empathy_individual_manager_dup_singleton ();
       connection = empathy_contact_get_connection (contact);
-      flags = empathy_individual_manager_get_flags_for_connection (
-          manager, connection);
 
-      enable = (flags & EMPATHY_INDIVIDUAL_MANAGER_CAN_ALIAS ||
-                flags & EMPATHY_INDIVIDUAL_MANAGER_CAN_GROUP);
+      enable = (empathy_connection_can_alias_personas (connection) &&
+                empathy_connection_can_group_personas (connection));
 
       g_object_unref (manager);
     }
