@@ -50,7 +50,6 @@
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
-#include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-ft-factory.h>
 
 void
@@ -231,7 +230,9 @@ empathy_icon_name_for_individual (FolksIndividual *individual)
 	FolksPresenceType folks_presence;
 	TpConnectionPresenceType presence;
 
-	folks_presence = folks_individual_get_presence_type (individual);
+	folks_presence =
+	    folks_presence_owner_get_presence_type (
+	        FOLKS_PRESENCE_OWNER (individual));
 	presence = empathy_folks_presence_type_to_tp (folks_presence);
 
 	return empathy_icon_name_for_presence (presence);
@@ -603,7 +604,7 @@ avatar_file_load_contents_cb (GObject      *object,
 	}
 
 	g_simple_async_result_set_op_res_gpointer (closure->result,
-			avatar_pixbuf_from_loader (loader), NULL);
+			avatar_pixbuf_from_loader (loader), g_object_unref);
 
 out:
 	g_simple_async_result_complete (closure->result);
@@ -631,7 +632,8 @@ empathy_pixbuf_avatar_from_individual_scaled_async (
 			callback, user_data,
 			empathy_pixbuf_avatar_from_individual_scaled_async);
 
-	avatar_file = folks_avatar_get_avatar (FOLKS_AVATAR (individual));
+	avatar_file =
+		folks_avatar_owner_get_avatar (FOLKS_AVATAR_OWNER (individual));
 	if (avatar_file == NULL)
 		goto out;
 
@@ -653,6 +655,7 @@ out:
 	g_object_unref (result);
 }
 
+/* Return a ref on the GdkPixbuf */
 GdkPixbuf *
 empathy_pixbuf_avatar_from_individual_scaled_finish (
 		FolksIndividual *individual,
@@ -661,6 +664,7 @@ empathy_pixbuf_avatar_from_individual_scaled_finish (
 {
 	GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (result);
 	gboolean result_valid;
+	GdkPixbuf *pixbuf;
 
 	g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), NULL);
 	g_return_val_if_fail (G_IS_SIMPLE_ASYNC_RESULT (simple), NULL);
@@ -673,7 +677,8 @@ empathy_pixbuf_avatar_from_individual_scaled_finish (
 			empathy_pixbuf_avatar_from_individual_scaled_async);
 	g_return_val_if_fail (result_valid, NULL);
 
-	return g_simple_async_result_get_op_res_gpointer (simple);
+	pixbuf = g_simple_async_result_get_op_res_gpointer (simple);
+	return pixbuf != NULL ? g_object_ref (pixbuf) : NULL;
 }
 
 GdkPixbuf *
@@ -1560,7 +1565,7 @@ empathy_window_iconify (GtkWindow *window, GtkStatusIcon *status_icon)
 
 	gtk_status_icon_get_geometry (status_icon, NULL, &icon_location, NULL);
 	gdk_window = gtk_widget_get_window (GTK_WIDGET (window));
-	dpy = gdk_x11_drawable_get_xdisplay (gdk_window);
+	dpy = GDK_WINDOW_XDISPLAY (gdk_window);
 
 	data[0] = icon_location.x;
 	data[1] = icon_location.y;
@@ -1570,7 +1575,7 @@ empathy_window_iconify (GtkWindow *window, GtkStatusIcon *status_icon)
 	XChangeProperty (dpy,
 			 GDK_WINDOW_XID (gdk_window),
 			 gdk_x11_get_xatom_by_name_for_display (
-				gdk_drawable_get_display (gdk_window),
+				gdk_window_get_display (gdk_window),
 			 "_NET_WM_ICON_GEOMETRY"),
 			 XA_CARDINAL, 32, PropModeReplace,
 			 (guchar *)&data, 4);
@@ -1834,11 +1839,66 @@ file_manager_receive_file_response_cb (GtkDialog *dialog,
 	GFile *file;
 
 	if (response == GTK_RESPONSE_OK) {
-		factory = empathy_ft_factory_dup_singleton ();
-		file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
+		GFile *parent;
+		GFileInfo *info;
+		guint64 free_space, file_size;
+		GError *error = NULL;
 
-		empathy_ft_factory_set_destination_for_incoming_handler
-			(factory, handler, file);
+		file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
+		parent = g_file_get_parent (file);
+		info = g_file_query_filesystem_info (parent,
+				G_FILE_ATTRIBUTE_FILESYSTEM_FREE,
+				NULL, &error);
+
+		g_object_unref (parent);
+
+		if (error != NULL) {
+			g_warning ("Error: %s", error->message);
+
+			g_object_unref (file);
+			return;
+		}
+
+		free_space = g_file_info_get_attribute_uint64 (info,
+				G_FILE_ATTRIBUTE_FILESYSTEM_FREE);
+		file_size = empathy_ft_handler_get_total_bytes (handler);
+
+		g_object_unref (info);
+
+		if (file_size > free_space) {
+			GtkWidget *message = gtk_message_dialog_new (
+				GTK_WINDOW (dialog),
+				GTK_DIALOG_MODAL,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_CLOSE,
+				_("Insufficient free space to save file"));
+			char *file_size_str, *free_space_str;
+
+			file_size_str = g_format_size_for_display (file_size);
+			free_space_str = g_format_size_for_display (free_space);
+
+			gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (message),
+				_("%s of free space are required to save this "
+				  "file, but only %s is available. Please "
+				  "choose another location."),
+				file_size_str, free_space_str);
+
+			gtk_dialog_run (GTK_DIALOG (message));
+
+			g_free (file_size_str);
+			g_free (free_space_str);
+			gtk_widget_destroy (message);
+
+			g_object_unref (file);
+
+			return;
+		}
+
+		factory = empathy_ft_factory_dup_singleton ();
+
+		empathy_ft_factory_set_destination_for_incoming_handler (
+				factory, handler, file);
 
 		g_object_unref (factory);
 		g_object_unref (file);
@@ -1892,3 +1952,47 @@ empathy_receive_file_with_file_chooser (EmpathyFTHandler *handler)
 	gtk_widget_show (widget);
 	g_free (title);
 }
+
+void
+empathy_make_color_whiter (GdkRGBA *color)
+{
+	const GdkRGBA white = { 1.0, 1.0, 1.0, 1.0 };
+
+	color->red = (color->red + white.red) / 2;
+	color->green = (color->green + white.green) / 2;
+	color->blue = (color->blue + white.blue) / 2;
+}
+
+static void
+menu_deactivate_cb (GtkMenu *menu,
+	gpointer user_data)
+{
+	/* FIXME: we shouldn't have to disconnect the signal (bgo #641327) */
+	g_signal_handlers_disconnect_by_func (menu,
+		     menu_deactivate_cb, user_data);
+
+	gtk_menu_detach (menu);
+}
+
+/* Convenient function to create a GtkMenu attached to @attach_to and detach
+ * it when the menu is not displayed any more. This is useful when creating a
+ * context menu that we want to get rid as soon as it as been displayed. */
+GtkWidget *
+empathy_context_menu_new (GtkWidget *attach_to)
+{
+	GtkWidget *menu;
+
+	menu = gtk_menu_new ();
+
+	gtk_menu_attach_to_widget (GTK_MENU (menu), attach_to, NULL);
+
+	/* menu is initially unowned but gtk_menu_attach_to_widget () taked its
+	 * floating ref. We can either wait that @attach_to releases its ref when
+	 * it will be destroyed (when leaving Empathy most of the time) or explicitely
+	 * detach the menu when it's not displayed any more.
+	 * We go for the latter as we don't want to keep useless menus in memory
+	 * during the whole lifetime of Empathy. */
+	g_signal_connect (menu, "deactivate", G_CALLBACK (menu_deactivate_cb), NULL);
+
+	return menu;
+}
